/* ********************************************************
   Current Loop Sensor
   using a 4mA-20mA water depth/pressure sensor for 500cm water depth
   https://werner.rothschopf.net/

   Hardware
   - a water pressure sensor 4mA - 20mA
     for an equivalent of 0 - 500cm water level

   by noiasca
   2020-07-19
 * ****************************************************** */

#include <NoiascaCurrentLoop.h>                  // download library from https://werner.rothschopf.net/

const byte sensorPin = A2;                       // ADC pin for the sensor
const uint16_t resistor = 150;                   // used pull down resistor in Ohm
const byte vref = 50;                            // VREF in Volt*10  (Uno 16MHz: 50, ProMini 8MHz: 3V3). Attention: an UNO powered by USB only will not have full 5V on VREF.
const uint16_t maxValue = 500;                   // max value of sensor at 20mA

CurrentLoopSensor currentLoopSensor(sensorPin, resistor, vref, maxValue);  // create the sensor object

void setup() {
  Serial.begin(115200);
  Serial.println(F("01_HelloWorld"));
  Serial.println(F("Current Loop Sensor"));
  currentLoopSensor.begin();                     // start the sensor
  currentLoopSensor.check();                     // remove this line if check shows no error, will save about 320 bytes program memory (flash)
}

void loop() {
  int myValue = currentLoopSensor.getValue();    // read sensor value into variable
  Serial.print(F("adc="));                       
  Serial.print(currentLoopSensor.getAdc());      // get the raw ADC value from the measurement. This should be called after the .getValue()
  Serial.print(F("\t myValue="));
  Serial.println(myValue);
  delay(2000);                                   // dirty delay to slow down
}
